observer_cli plugin for espace.
Copyright © 2021, Fred Youhanaie
Authors: Fred Youhanaie (fyrlang@anydata.co.uk).
observer_cli plugin for espace.
| attributes/1 | The callback for the attributes section. |
| load_config/0 | Load the default observer_cli plugin env data. |
| load_config/1 | Load the supplied observer_cli plugin env data. |
| sheet_body/1 | The callback to return all the counts for all instances. |
| sheet_header/0 | The callback to return the column headings. |
attributes(Prev_state::term()) -> {[any()], term()}
The callback for the attributes section.
Presently this will return an empty list.load_config() -> ok
Load the default observer_cli plugin env data.
load_config/1 for details.
load_config(Config::term()) -> ok
Load the supplied observer_cli plugin env data.
observer_cli to
access the espace plugin.
sheet_body(Prev_state::term()) -> {[list()], term()}
The callback to return all the counts for all instances.
sheet_header() -> [#{title => string(), width => pos_integer(), shortcut => string()}]
The callback to return the column headings
Generated by EDoc